Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(372)

Unified Diff: apps/app_shim/unix_domain_socket_acceptor.h

Issue 305973002: Rename IPC::ChannelFactory to ChannelHandleAcceptor. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 6 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: apps/app_shim/unix_domain_socket_acceptor.h
diff --git a/ipc/ipc_channel_factory.h b/apps/app_shim/unix_domain_socket_acceptor.h
similarity index 56%
rename from ipc/ipc_channel_factory.h
rename to apps/app_shim/unix_domain_socket_acceptor.h
index 3115601b4917e55f43e75bed27e3d6797514d482..98e100a6dd2c30252f1f28f9a0d86a6a7577c115 100644
--- a/ipc/ipc_channel_factory.h
+++ b/apps/app_shim/unix_domain_socket_acceptor.h
@@ -2,36 +2,35 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef IPC_IPC_CHANNEL_FACTORY_H_
-#define IPC_IPC_CHANNEL_FACTORY_H_
+#ifndef APPS_APP_SHIM_UNIX_DOMAIN_SOCKET_ACCEPTOR_H_
+#define APPS_APP_SHIM_UNIX_DOMAIN_SOCKET_ACCEPTOR_H_
#include "base/files/file_path.h"
#include "base/message_loop/message_loop.h"
#include "ipc/ipc_channel_handle.h"
-#include "ipc/ipc_export.h"
-namespace IPC {
+namespace apps {
-// A ChannelFactory listens on a UNIX domain socket. When a client connects to
-// the socket, it accept()s the connection and passes the new FD to the
-// delegate. The delegate is then responsible for creating a new IPC::Channel
-// for the FD.
-class IPC_EXPORT ChannelFactory : public base::MessageLoopForIO::Watcher {
+// A UnixDomainSocketAcceptor listens on a UNIX domain socket. When a
+// client connects to the socket, it accept()s the connection and
+// passes the new FD to the delegate. The delegate is then responsible
+// for creating a new IPC::Channel for the FD.
+class UnixDomainSocketAcceptor : public base::MessageLoopForIO::Watcher {
public:
class Delegate {
public:
// Called when a client connects to the factory. It is the delegate's
// responsibility to create an IPC::Channel for the handle, or else close
// the file descriptor contained therein.
- virtual void OnClientConnected(const ChannelHandle& handle) = 0;
+ virtual void OnClientConnected(const IPC::ChannelHandle& handle) = 0;
// Called when an error occurs and the channel is closed.
virtual void OnListenError() = 0;
};
- ChannelFactory(const base::FilePath& path, Delegate* delegate);
+ UnixDomainSocketAcceptor(const base::FilePath& path, Delegate* delegate);
- virtual ~ChannelFactory();
+ virtual ~UnixDomainSocketAcceptor();
// Call this to start listening on the socket.
bool Listen();
@@ -45,14 +44,14 @@ class IPC_EXPORT ChannelFactory : public base::MessageLoopForIO::Watcher {
virtual void OnFileCanWriteWithoutBlocking(int fd) OVERRIDE;
base::MessageLoopForIO::FileDescriptorWatcher
- server_listen_connection_watcher_;
+ server_listen_connection_watcher_;
base::FilePath path_;
Delegate* delegate_;
int listen_fd_;
- DISALLOW_COPY_AND_ASSIGN(ChannelFactory);
+ DISALLOW_COPY_AND_ASSIGN(UnixDomainSocketAcceptor);
};
-} // namespace IPC
+} // namespace apps
-#endif // IPC_IPC_CHANNEL_FACTORY_H_
+#endif // APPS_APP_SHIM_UNIX_DOMAIN_SOCKET_ACCEPTOR_H_
« no previous file with comments | « apps/app_shim/test/app_shim_host_manager_test_api_mac.cc ('k') | apps/app_shim/unix_domain_socket_acceptor.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698